==> huaweicloudsdkobs-3.1.109-py2.py3-none-any.whl: huaweicloudsdkobs/v1/model/access_control_list.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AccessControlList:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    xml_name = "AccessControlList"

    sensitive_list = []

    openapi_types = {
        'grant': 'list[Grant]'
    }

    attribute_map = {
        'grant': 'Grant'
    }

    def __init__(self, grant=None):
        """AccessControlList

        The model defined in huaweicloud sdk

        :param grant: 
        :type grant: list[:class:`huaweicloudsdkobs.v1.Grant`]
        """
        
        

        self._grant = None
        self.discriminator = None

        if grant is not None:
            self.grant = grant

    @property
    def grant(self):
        """Gets the grant of this AccessControlList.

        :return: The grant of this AccessControlList.
        :rtype: list[:class:`huaweicloudsdkobs.v1.Grant`]
        """
        return self._grant

    @grant.setter
    def grant(self, grant):
        """Sets the grant of this AccessControlList.

        :param grant: The grant of this AccessControlList.
        :type grant: list[:class:`huaweicloudsdkobs.v1.Grant`]
        """
        self._grant = grant

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccessControlList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkobs-3.1.148-py2.py3-none-any.whl: huaweicloudsdkobs/v1/model/access_control_list.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AccessControlList:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    xml_name = "AccessControlList"

    sensitive_list = []

    openapi_types = {
        'grant': 'list[Grant]'
    }

    attribute_map = {
        'grant': 'Grant'
    }

    def __init__(self, grant=None):
        r"""AccessControlList

        The model defined in huaweicloud sdk

        :param grant: 
        :type grant: list[:class:`huaweicloudsdkobs.v1.Grant`]
        """
        
        

        self._grant = None
        self.discriminator = None

        if grant is not None:
            self.grant = grant

    @property
    def grant(self):
        r"""Gets the grant of this AccessControlList.

        :return: The grant of this AccessControlList.
        :rtype: list[:class:`huaweicloudsdkobs.v1.Grant`]
        """
        return self._grant

    @grant.setter
    def grant(self, grant):
        r"""Sets the grant of this AccessControlList.

        :param grant: The grant of this AccessControlList.
        :type grant: list[:class:`huaweicloudsdkobs.v1.Grant`]
        """
        self._grant = grant

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccessControlList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
